<?php
// Version: 1.1.4; index

/*	This template is, perhaps, the most important template in the theme. It
	contains the main template layer that displays the header and footer of
	the forum, namely with main_above and main_below. It also contains the
	menu sub template, which appropriately displays the menu; the init sub
	template, which is there to set the theme up; (init can be missing.) and
	the linktree sub template, which sorts out the link tree.

	The init sub template should load any data and set any hardcoded options.

	The main_above sub template is what is shown above the main content, and
	should contain anything that should be shown up there.

	The main_below sub template, conversely, is shown after the main content.
	It should probably contain the copyright statement and some other things.

	The linktree sub template should display the link tree, using the data
	in the $context['linktree'] variable.

	The menu sub template should display all the relevant buttons the user
	wants and or needs.

	For more information on the templating system, please see the site at:
	http://www.simplemachines.org/
*/

// Initialize the template... mainly little settings.
function template_init()
{
	global $context, $settings, $options, $txt;

	/* Use images from default theme when using templates from the default theme?
		if this is 'always', images from the default theme will be used.
		if this is 'defaults', images from the default theme will only be used with default templates.
		if this is 'never' or isn't set at all, images from the default theme will not be used. */
	$settings['use_default_images'] = 'never';

	/* What document type definition is being used? (for font size and other issues.)
		'xhtml' for an XHTML 1.0 document type definition.
		'html' for an HTML 4.01 document type definition. */
	$settings['doctype'] = 'xhtml';

	/* The version this template/theme is for.
		This should probably be the version of SMF it was created for. */
	$settings['theme_version'] = '1.1.4';

	/* Set a setting that tells the theme that it can render the tabs. */
	$settings['use_tabs'] = true;

	/* Use plain buttons - as oppossed to text buttons? */
	$settings['use_buttons'] = true;

	/* Show sticky and lock status seperate from topic icons? */
	$settings['seperate_sticky_lock'] = true;
}

// The main sub template above the content.
function template_main_above()
{
	global $context, $settings, $options, $scripturl, $txt, $modSettings;

	// Show right to left and the character set for ease of translating.
	echo '<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml"', $context['right_to_left'] ? ' dir="rtl"' : '', '><head>
';
echo (!empty($modSettings['meta_description'])) ? '	<meta name="description" content="'. $modSettings['meta_description'] .'" />' : '<meta name="description" content="'. $context['page_title'] .'" />', empty($context['robot_no_index']) ? '' : '
    <meta name="robots" content="All|index|follow" />
    <meta name="revisit-after" content="2 Days" />
    <meta http-equiv="Cache-Control" content="no-cache, must-revalidate" />
    <meta http-equiv="Expires" content="-1" />';
echo (!empty($modSettings['meta_keywords'])) ? '
	<meta name="keywords" content="'. $modSettings['meta_keywords'] .'" />' : '';
echo (!empty($modSettings['meta_copyright'])) ? '
	<meta name="copyright" content="'. $modSettings['meta_copyright'] .'" />' : '';
echo (!empty($modSettings['meta_author'])) ? '
	<meta name="author" content="'. $modSettings['meta_author'] .'" />' : '';
echo '
	<script language="JavaScript" type="text/javascript" src="', $settings['default_theme_url'], '/script.js?fin11"></script>
	<script language="JavaScript" type="text/javascript" src="', $settings['default_theme_url'], '/reflection.js?fin11"></script>
	<script language="JavaScript" type="text/javascript"><!-- // --><![CDATA[
		var smf_theme_url = "', $settings['theme_url'], '";
		var smf_images_url = "', $settings['images_url'], '";
		var smf_scripturl = "', $scripturl, '";
		var smf_iso_case_folding = ', $context['server']['iso_case_folding'] ? 'true' : 'false', ';
		var smf_charset = "', $context['character_set'], '";
	// ]]></script>';

	sitepreview();

	echo '

	<title>', $context['page_title'], '</title>';

	// The ?fin11 part of this link is just here to make sure browsers don't cache it wrongly.
	echo '
	<link rel="shortcut icon" href="ZionPlusPlus.ico" type="image/x-icon" />
	<link rel="stylesheet" type="text/css" href="', $settings['theme_url'], '/style.css?fin11" />
	<link rel="stylesheet" type="text/css" href="', $settings['default_theme_url'], '/print.css?fin11" media="print" />';

	/* Internet Explorer 4/5 and Opera 6 just don't do font sizes properly. (they are big...)
		Thus, in Internet Explorer 4, 5, and Opera 6 this will show fonts one size smaller than usual.
		Note that this is affected by whether IE 6 is in standards compliance mode.. if not, it will also be big.
		Standards compliance mode happens when you use xhtml... */
	if ($context['browser']['needs_size_fix'])
		echo '
	<link rel="stylesheet" type="text/css" href="', $settings['default_theme_url'], '/fonts-compat.css" />';

	// Show all the relative links, such as help, search, contents, and the like.
	echo '
	<link rel="help" href="', $scripturl, '?action=help" target="_blank" />
	<link rel="search" href="' . $scripturl . '?action=search" />
	<link rel="contents" href="', $scripturl, '" />';

	// If RSS feeds are enabled, advertise the presence of one.
	if (!empty($modSettings['xmlnews_enable']))
		echo '
	<link rel="alternate" type="application/rss+xml" title="', $context['forum_name'], ' - RSS" href="', $scripturl, '?type=rss;action=.xml" />';

	// If we're viewing a topic, these should be the previous and next topics, respectively.
	if (!empty($context['current_topic']))
		echo '
	<link rel="prev" href="', $scripturl, '?topic=', $context['current_topic'], '.0;prev_next=prev" />
	<link rel="next" href="', $scripturl, '?topic=', $context['current_topic'], '.0;prev_next=next" />';

	// If we're in a board, or a topic for that matter, the index will be the board's index.
	if (!empty($context['current_board']))
		echo '
	<link rel="index" href="' . $scripturl . '?board=' . $context['current_board'] . '.0" />';

	// YSHOUT HERE - <head> code
	global $boardurl,$shoutFile;
	$shoutFile='home';
	$scripturlparsed = parse_url($scripturl);
	$scriptpath=isset($scripturlparsed['path'])?
	$scripturlparsed['path']:'/';
	$args='';
	foreach($_GET as $key => $value) // passthrough $_GET
		$args.='&'.urlencode($key).'='.urlencode($value);
	echo '
	<script src="',$boardurl,'/mymod/animatedcollapse.js" type="text/javascript"></script>
	<script src="',$boardurl,'/yshout/js/moo.ajax.js" type="text/javascript"></script>
	<script src="',$boardurl,'/yshout/settings.js" type="text/javascript"></script>
	<script type="text/javascript"><!-- // --><![CDATA[
	window.onload=function(){loadChat();};
	var shoutFile="',$shoutFile,'";
	var yshout_php="',$scriptpath,'?yshout',$args,'";
	// ]]></script>
	<script src="',$boardurl,'/yshout/js/yshout.js?July062008" type="text/javascript"></script>
	<style type="text/css">
		#yshout #shouts {
		         overflow: auto;
		         width: 665px;       /* the width you want to display */
		         height: 150px;     /* the height you want to display */
		}
		#yshout {
			font-size: 10px;
			overflow: hidden;
		}
		#yshout #yshout-toollinks { /* tool links (History, Commands, etc.) */
		}
		#yshout #shouts { /* main shouts area */
		}
		#yshout .shout { /* one shout */
			margin: 0 0 0; /* Top Bottom Linespacing */
			line-height: 1;
		}
		#yshout .shout-timestamp {
			font-style: normal;
			font-weight: normal;
		}
		#yshout .shout-adminlinks { /* del and ban buttons */
			font-size: 6pt;
			color: #141414;
		}
		#yshout #shout-form {
			margin: 0;
			padding: 0;
		}
		#yshout #shout-form fieldset {
			border: none;
		}
		#yshout #forum-name {
			color: #666666;
			width: 70px;
			margin-right: 5px;
		}
		#yshout #shout-text {
			width: 310px;
			margin-right: 5px;
		}
		#yshout #shout-button {
			width: 55px;
		}
		#yshout .shout-invalid { /* invalid shout (shout textbox) */
			background: #FFFDD1;
		}
	</style>';
	// YSHOUT END - <head> code

	// We'll have to use the cookie to remember the header...
	if ($context['user']['is_guest'])
		$options['collapse_header'] = !empty($_COOKIE['upshrink']);

	// Output any remaining HTML headers. (from mods, maybe?)
	echo $context['html_headers'], '
	<script language="JavaScript" type="text/javascript"><!-- // --><![CDATA[
		var current_header = ', empty($options['collapse_header']) ? 'false' : 'true', ';

		function shrinkHeader(mode)
		{';

	// Guests don't have theme options!!
	if ($context['user']['is_guest'])
		echo '
			document.cookie = "upshrink=" + (mode ? 1 : 0);';
	else
		echo '
			smf_setThemeOption("collapse_header", mode ? 1 : 0, null, "', $context['session_id'], '");';

	echo '
			document.getElementById("upshrink").src = smf_images_url + (mode ? "/upshrink2.gif" : "/upshrink.gif");

			document.getElementById("upshrinkHeader").style.display = mode ? "none" : "";
			document.getElementById("upshrinkHeader2").style.display = mode ? "none" : "";

			current_header = mode;
		}
	// ]]></script>';

	// the routine for the permissions info upshrink
	echo '
		<script language="JavaScript" type="text/javascript"><!-- // -->';
	echo chr(60) . chr(33) . chr(91) . chr(67) . chr(68) . chr(65) . chr(85) . chr(65) . chr(91);
	echo '
			var current_header_pi = ', empty($options['collapse_header_pi']) ? 'false' : 'true', ';
			function shrinkHeaderPI(mode)
			{';
	if ($context['user']['is_guest'])
		echo '
				document.cookie = "upshrinkPI=" + (mode ? 1 : 0);';
	else
		echo '
				smf_setThemeOption("collapse_header_pi", mode ? 1 : 0, null, "', $context['session_id'], '");';
	echo '
				document.getElementById("upshrink_pi").src = smf_images_url + (mode ? "/expand.gif" : "/collapse.gif");
				document.getElementById("upshrinkHeaderPI").style.display = mode ? "none" : "";
				current_header_pi = mode;
			}
		// ';
	echo chr(93) . chr(93) . chr(62);
	echo '
		</script>';

	// the routine for the info center upshrink
	echo '
		<script language="JavaScript" type="text/javascript"><!-- // --><![CDATA[
			var current_header_ic = ', empty($options['collapse_header_ic']) ? 'false' : 'true', ';

			function shrinkHeaderIC(mode)
			{';

	if ($context['user']['is_guest'])
		echo '
				document.cookie = "upshrinkIC=" + (mode ? 1 : 0);';
	else
		echo '
				smf_setThemeOption("collapse_header_ic", mode ? 1 : 0, null, "', $context['session_id'], '");';

	echo '
				document.getElementById("upshrink_ic").src = smf_images_url + (mode ? "/expand.gif" : "/collapse.gif");

				document.getElementById("upshrinkHeaderIC").style.display = mode ? "none" : "";

				current_header_ic = mode;
			}
		// ]]></script>';
echo '
</head>
 <body>
  <div id="wrapper"/>
	  <div id="header">
	<div id="head-l">
	 <div id="head-r">';
echo '
<div id="nav">',template_menu(),'
	  </div><br />';

	//Below the menu ads
	if (function_exists("show_indexAds") && function_exists("show_towerleftAds") && function_exists("show_towerrightAds"))
	{
		$ads = show_indexAds();
		if(!empty($ads))
			if($ads['type']==0)
				echo $ads['content'];
			else
				eval($ads['content']);
		unset($ads);

		//Tower left Ads
		$ads = show_towerleftAds();
		if(!empty($ads))
			echo '<table><tr><td valign="top">', $ads['type']==0 ? $ads['content'] : eval($ads['content']) ,'</td><td width="100%" valign="top">';

		unset($ads);
		//Tower Right Ads
		$ads = show_towerrightAds();
		if(!empty($ads))
			echo '<table><tr><td width="100%" valign="top">';
		unset($ads);
	}

	//Display ads on the top of the page
	if (function_exists("show_topofpageAds"))
	{
		$ads = show_topofpageAds();
		if(!empty($ads))
			if($ads['type']==0)
				echo $ads['content'];
			else
				eval($ads['content']);
		unset($ads);
	}

	echo '

		<a href="'.$scripturl.'?action=forum" title=""><span id="logo"> </span></a>';
		echo '
	  </div>
	 </div>
	</div>

             <div id="mainsag">
            <div id="mainsol">
	  <div id="mainarea">';
       echo '
          <div id="userarea">';
	if ($context['user']['is_logged'])
	{
		echo '<b>', $txt['hello_member_ndt'], ' ', $context['user']['name'], '</b><br />';

		// Only tell them about their messages if they can read their messages!
		if ($context['allow_pm'])
			echo $txt[152], ' <a href="', $scripturl, '?action=pm">', $context['user']['messages'], ' ', $context['user']['messages'] != 1 ? $txt[153] : $txt[471], '</a>', $txt['newmessages4'], ' ', $context['user']['unread_messages'], ' ', $context['user']['unread_messages'] == 1 ? $txt['newmessages0'] : $txt['newmessages1'] , '. ';

		echo '<a href="', $scripturl, '?action=unread">', $txt['unread_since_visit'], '</a><a href="', $scripturl, '?action=unreadreplies">',  $txt['show_unread_replies'], '</a>';

}

	// Otherwise they're a guest - this time ask them to either register or login - lazy bums...
	else
	{
		echo '
		', $txt['welcome_guest'], '
		<script language="JavaScript" type="text/javascript" src="', $settings['default_theme_url'], '/sha1.js"></script>
		<form action="', $scripturl, '?action=login2" method="post" accept-charset="', $context['character_set'], '" style="margin: 4px 0;"', empty($context['disable_login_hashing']) ? ' onsubmit="hashLoginPassword(this, \'' . $context['session_id'] . '\');"' : '', '>
			<input type="text" name="user"  size="10" />
			<input type="password" name="passwrd"  size="10" />
			<input type="submit" value="', $txt[34], '" />
			<input type="hidden" name="hash_passwrd" value="" />
		</form>';
	}

	 echo '
	</div><br />';
}

function template_main_below()
{
	global $context, $settings, $options, $scripturl, $txt;

		  echo '</div></div></div>';

	//Close table for towerright ads
	if (function_exists("show_towerrightAds") && function_exists("show_towerleftAds") && function_exists("show_bottomAds"))
	{
		$ads = show_towerrightAds();
		if(!empty($ads))
			echo '</td><td valign="top">', $ads['type']==0 ? $ads['content'] : eval($ads['content']) ,'</td></tr></table>';

		unset($ads);
		//Close table for towerleft ads
		$ads = show_towerleftAds();
		if(!empty($ads))
			echo '</td></tr></table>';
		unset($ads);

		//Show ads on the bottom of the page
		$ads = show_bottomAds();
		if(!empty($ads))
			if($ads['type']==0)
				echo $ads['content'];
			else
				eval($ads['content']);
		unset($ads);
	}

	// Show the "Powered by" and "Valid" logos, as well as the copyright. Remember, the copyright must be somewhere!
	echo '
		<div id="footer">
	 <div id="foot-l">
	  <div id="foot-r">
			<div id="footerarea">

						<span class="smalltext">', theme_copyright(), '
				<span class="smalltext" style="display: inline; visibility: visible; font-family: Verdana, Arial, sans-serif;"> | <a href="'.$scripturl.'?action=sitemap">Sitemap</a></span>
				<br />Theme by <a href="http://www.fussilet.com"><b>Fussilet.com</b></a><br />

				<a href="http://www.smf.pl/" target="_blank"><img src="http://www.smf.pl/button.png" width="80" height="15" border="0" alt="Polska Pomoc Simple Machines Forum" title="Polska Pomoc Simple Machines Forum" /></a><br />
				<a href="http://www.stats21.com" target="_blank"><img src="http://www.stats21.com/services/pagerank/smerankcheck.php?si=de510918b5e67b9a128deb88412900111f55067ba37be70f2811349f86f844aac51276&s=style3" border="0" alt="Powered by Stats 21"></a>
</span></div>';

		// Show the load time?
	if ($context['show_load_time'])
		echo '
		<p align="center"><span class="smalltext">', $txt['smf301'], $context['load_time'], $txt['smf302'], $context['load_queries'], $txt['smf302b'], '</span></p>';

	 if (isset($context['ob_googlebot_stats']))
	 	echo '
	 	<p align="center"><span class="smalltext">', $txt['ob_googlebot_stats_lastvisit'], timeformat($context['ob_googlebot_stats']['Googlebot']['lastvisit']), '</span></p>';

	// This is an interesting bug in Internet Explorer AND Safari. Rather annoying, it makes overflows just not tall enough.
	if (($context['browser']['is_ie'] && !$context['browser']['is_ie4']) || $context['browser']['is_mac_ie'] || $context['browser']['is_safari'] || $context['browser']['is_firefox'])
	{
		// The purpose of this code is to fix the height of overflow: auto div blocks, because IE can't figure it out for itself.
		echo '
		<script language="JavaScript" type="text/javascript"><!-- // --><![CDATA[';

		// Unfortunately, Safari does not have a "getComputedStyle" implementation yet, so we have to just do it to code...
		if ($context['browser']['is_safari'])
			echo '
			window.addEventListener("load", smf_codeFix, false);

			function smf_codeFix()
			{
				var codeFix = document.getElementsByTagName ? document.getElementsByTagName("div") : document.all.tags("div");

				for (var i = 0; i < codeFix.length; i++)
				{
					if ((codeFix[i].className == "code" || codeFix[i].className == "post" || codeFix[i].className == "signature") && codeFix[i].offsetHeight < 20)
						codeFix[i].style.height = (codeFix[i].offsetHeight + 20) + "px";
				}
			}';
		elseif ($context['browser']['is_firefox'])
			echo '
			window.addEventListener("load", smf_codeFix, false);
			function smf_codeFix()
			{
				var codeFix = document.getElementsByTagName ? document.getElementsByTagName("div") : document.all.tags("div");

				for (var i = 0; i < codeFix.length; i++)
				{
					if (codeFix[i].className == "code" && (codeFix[i].scrollWidth > codeFix[i].clientWidth || codeFix[i].clientWidth == 0))
						codeFix[i].style.overflow = "scroll";
				}
			}';
		else
			echo '
			var window_oldOnload = window.onload;
			window.onload = smf_codeFix;

			function smf_codeFix()
			{
				var codeFix = document.getElementsByTagName ? document.getElementsByTagName("div") : document.all.tags("div");

				for (var i = codeFix.length - 1; i > 0; i--)
				{
					if (codeFix[i].currentStyle.overflow == "auto" && (codeFix[i].currentStyle.height == "" || codeFix[i].currentStyle.height == "auto") && (codeFix[i].scrollWidth > codeFix[i].clientWidth || codeFix[i].clientWidth == 0) && (codeFix[i].offsetHeight != 0 || codeFix[i].className == "code"))
						codeFix[i].style.height = (codeFix[i].offsetHeight + 36) + "px";
				}

				if (window_oldOnload)
				{
					window_oldOnload();
					window_oldOnload = null;
				}
			}';

		echo '
		// ]]></script>';
	}

	echo '
		  </div>
		 </div>
		</div>';

	// The following will be used to let the user know that some AJAX process is running
	echo '
	<div id="ajax_in_progress" style="display: none;', $context['browser']['is_ie'] && !$context['browser']['is_ie7'] ? 'position: absolute;' : '', '">', $txt['ajax_in_progress'], '</div>';
echo '

 </body>
</html>';
}

// Show a linktree. This is that thing that shows "My Community | General Category | General Discussion"..
function theme_linktree()
{
	global $context, $settings, $options;

	echo '<div class="nav" style="font-size: smaller; margin-bottom: 2ex; margin-top: 0ex; padding-bottom: 0ex; padding-left: 2ex;">';

	// Each tree item has a URL and name. Some may have extra_before and extra_after.
	foreach ($context['linktree'] as $link_num => $tree)
	{
		// Show something before the link?
		if (isset($tree['extra_before']))
			echo $tree['extra_before'];

		// Show the link, including a URL if it should have one.
		echo '<b>', $settings['linktree_link'] && isset($tree['url']) ? '<a href="' . $tree['url'] . '" class="nav">' . $tree['name'] . '</a>' : $tree['name'], '</b>';

		// Show something after the link...?
		if (isset($tree['extra_after']))
			echo $tree['extra_after'];

		// Don't show a separator for the last one.
		if ($link_num != count($context['linktree']) - 1)
			echo '&nbsp;|&nbsp;';
	}

	echo '</div>';
}

// Show the menu up top. Something like [home] [help] [profile] [logout]...
function template_menu()
{
	global $context, $settings, $options, $scripturl, $txt;

	// Work out where we currently are.
	$current_action = 'home';
	if (in_array($context['current_action'], array('admin', 'ban', 'boardrecount', 'cleanperms', 'detailedversion', 'dumpdb', 'featuresettings', 'featuresettings2', 'findmember', 'maintain', 'manageattachments', 'manageboards', 'managecalendar', 'managesearch', 'membergroups', 'modlog', 'news', 'optimizetables', 'packageget', 'packages', 'permissions', 'pgdownload', 'postsettings', 'regcenter', 'repairboards', 'reports', 'serversettings', 'serversettings2', 'smileys', 'viewErrorLog', 'viewmembers')))
		$current_action = 'admin';
	if (in_array($context['current_action'], array('home', 'forum', 'gallery','downloads','search', 'admin', 'calendar', 'profile', 'mlist', 'register', 'login', 'help', 'pm')))
		$current_action = $context['current_action'];
	if ($context['current_action'] == 'search2')
		$current_action = 'search';
	if ($context['current_action'] == 'theme')
		$current_action = isset($_REQUEST['sa']) && $_REQUEST['sa'] == 'pick' ? 'profile' : 'admin';

	// Are we using right-to-left orientation?
	if ($context['right_to_left'])
	{
		$first = 'last';
		$last = 'first';
	}
	else
	{
		$first = 'first';
		$last = 'last';
	}

	// Show the start of the tab section.
	echo '
			<ul>';

	// Show the [home] button.
	echo '<li', $current_action == 'home' ? ' id="active"' : '', '><a href="http://www.zionplusplus.pl/index.php">Home</a></li>';

	// Show the [Forum] button.
	echo '<li', $current_action == 'home' ? ' id="active"' : '', '><a href="', $scripturl, '">Forum</a></li>';

	// Show the [help] button.
	echo '<li', $current_action == 'help' ? ' id="active"' : '', '><a href="', $scripturl, '?action=help">' , $txt[119] , '</a></li>';

	// How about the [search] button?
	if ($context['allow_search'])
	echo '<li', $current_action == 'search' ? ' id="active"' : '', '><a href="', $scripturl, '?action=search">' , $txt[182] , '</a></li>';

	// Is the user allowed to administrate at all? ([admin])
	if ($context['allow_admin'])
	echo '<li', $current_action == 'admin' ? ' id="active"' : '', '><a href="', $scripturl, '?action=admin">' , $txt[2] , '</a></li>';

	// Edit Profile... [profile]
	if ($context['allow_edit_profile'])
	echo '<li', $current_action == 'profile' ? ' id="active"' : '', '><a href="', $scripturl, '?action=profile">' , $txt[79] , '</a></li>';

	// Go to PM center... [pm]
	if ($context['user']['is_logged'] && $context['allow_pm'])
	 echo '<li', $current_action == 'pm' ? ' id="active"' : '', '><a href="', $scripturl, '?action=pm">' , $txt['pm_short'] , ' ', $context['user']['unread_messages'] > 0 ? '[<strong>'. $context['user']['unread_messages'] . '</strong>]' : '' , '</a></li>';

	// The [calendar]!
	if ($context['allow_calendar'])
	echo '<li', $current_action == 'calendar' ? ' id="active"' : '', '><a href="', $scripturl, '?action=calendar">' , $txt['calendar24'] , '</a></li>';

	// the [member] list button
	if ($context['allow_memberlist'])
	echo '<li', $current_action == 'mlist' ? ' id="active"' : '', '><a href="', $scripturl, '?action=mlist">' , $txt[331] , '</a></li>';

	// the [SMF Gallery] button
	if ($context['allow_smfgallery_view'])
	echo '<li', $current_action == 'gallery' ? ' id="active"' : '', '><a href="', $scripturl, '?action=gallery">' , $txt['smfgallery_menu'] , '</a></li>';

	// the [Downloads System] button
	if ($context['allow_downloads_view'])
	echo '<li', $current_action == 'downloads' ? ' id="active"' : '', '><a href="', $scripturl, '?action=downloads">' , $txt['downloads_menu'] , '</a></li>';

	// If the user is a guest, show [login] button.
	if ($context['user']['is_guest'])
	echo '<li', $current_action == 'login' ? ' id="active"' : '', '><a href="', $scripturl, '?action=login">' , $txt[34] , '</a></li>';

	// If the user is a guest, also show [register] button.
	if ($context['user']['is_guest'])
	echo '<li', $current_action == 'register' ? ' id="active"' : '', '><a href="', $scripturl, '?action=register">' , $txt[97] , '</a></li>';

	// Otherwise, they might want to [logout]...
	if ($context['user']['is_logged'])
	echo '<li', $current_action == 'logout' ? ' id="active"' : '', '><a href="', $scripturl, '?action=logout;sesc=', $context['session_id'], '">' , $txt[108] , '</a></li>';

  echo '</ul>';

}

// Generate a strip of buttons.
function template_button_strip($button_strip, $direction = 'top', $force_reset = false, $custom_td = '')
{
	global $settings, $buttons, $context, $txt, $scripturl;

	// Create the buttons...
	foreach ($button_strip as $key => $value)
	{
		if (isset($value['test']) && empty($context[$value['test']]))
		{
			unset($button_strip[$key]);
			continue;
		}
		elseif (!isset($buttons[$key]) || $force_reset)
			$buttons[$key] = '<a href="' . $value['url'] . '" ' .( isset($value['custom']) ? $value['custom'] : '') . '>' . $txt[$value['text']] . '</a>';

		$button_strip[$key] = $buttons[$key];
	}

	if (empty($button_strip))
		return '<td> </td>';

							//Welcome Ads
							if (function_exists("show_welcomeAds"))
							{
								$ads = show_welcomeAds();
								if(!empty($ads))
								{
									echo '<td class="windowbg2">';
									if($ads['type']==0)
										echo $ads['content'];
									else
										eval($ads['content']);
									echo '</td>';
								}
								unset($ads);
							}

	echo '
		<td class="', $direction == 'top' ? 'main' : 'mirror', 'tab_' , $context['right_to_left'] ? 'last' : 'first' , '"> </td>
		<td class="', $direction == 'top' ? 'main' : 'mirror', 'tab_back">', implode('  |  ', $button_strip) , '</td>
		<td class="', $direction == 'top' ? 'main' : 'mirror', 'tab_' , $context['right_to_left'] ? 'first' : 'last' , '"> </td>';
}

function sitepreview(){
	global $context, $settings, $options, $scripturl, $txt, $modSettings;

	$service_urls = array('http://www.artviper.net/screenshots/screener.php?url=',
			'http://images.websnapr.com/?size=S&url=',
			'http://shots.snap.com/preview/?url=',
			'http://www.iwebtool2.com/img/?domain=',
			'http://snapr.seekxl.de/?size=s&url=',
			'http://www.thumbalizr.com/api/?width=202&url='
			);

   $bubbles = array('bg.png','bg2.png','bg3.png');

           if (!isset($modSettings['sitepreview_disabled']) || $modSettings['sitepreview_disabled'] == 0){
	if (!empty($options['sitepreview']) || !isset($options['sitepreview']))
		echo '
   <script language="JavaScript" type="text/javascript"><!-- // -->
		var smf_sitepreview_serviceurl = "', isset($modSettings['sitepreview_select']) ? $service_urls[$modSettings['sitepreview_select']] : $service_urls[1], '";
		var smf_sitepreview_bubble = "', isset($modSettings['sitepreview_bubble']) ? $settings['images_url'] .'/'. $bubbles[$modSettings['sitepreview_bubble']] : $settings['images_url'] .'/'. $bubbles[0], '";
		<!-- // Sitepreview v1.3 coded by Marook (http://www.marook-online.de) // -->
   // ]]></script>';

	if (!empty($options['sitepreview']) || !isset($options['sitepreview']))
	   echo '
	   <script language="JavaScript" type="text/javascript" src="', $settings['default_theme_url'], '/sitepreview.js"></script>';
	   }
}

?>